@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::FromClass;
 
-our $DATE = '2014-08-04'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-04-23'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,7 +18,7 @@ our %SPEC;
 
 $SPEC{gen_func_from_class} = {
     v => 1.1,
-    summary => 'Generate function from a class',
+    summary => 'Generate function (and its Rinci metadata) from a class',
     description => <<'_',
 
 `gen_func_from_class` will create a function and Rinci metadata from a
@@ -155,7 +155,10 @@ sub gen_func_from_class {
                     };
                     if (exists $v->{default}) {
                         if (ref($v->{default}) eq 'CODE') {
-                            $as->{default} = $v->{default}->();
+                            # XXX we're required to send $self to coderef, so we
+                            # don't do it yet.
+
+                            #$as->{default} = $v->{default}->($obj);
                         } else {
                             $as->{default} = $v->{default};
                         }
@@ -213,7 +216,7 @@ Perinci::Sub::Gen::FromClass - Generate function (and its Rinci metadata) from a
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::Sub::Gen::FromClass (from Perl distribution Perinci-Sub-Gen-FromClass), released on 2014-08-04.
+This document describes version 0.03 of Perinci::Sub::Gen::FromClass (from Perl distribution Perinci-Sub-Gen-FromClass), released on 2015-04-23.
 
 =head1 SYNOPSIS
 
@@ -265,7 +268,7 @@ This module helps you create that function from a class.
 
 =head2 gen_func_from_class(%args) -> [status, msg, result, meta]
 
-Generate function from a class.
+Generate function (and its Rinci metadata) from a class.
 
 C<gen_func_from_class> will create a function and Rinci metadata from a
 {Mo,Moo,Moose,Mouse} class. Given a class like this:
@@ -341,8 +344,6 @@ Generated function's summary.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -352,11 +353,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-A hash containing generated function, metadata (hash)
-
-=head1 TODO
-
-Translate C<isa> option in C<has> into argument schema.
+Return value: A hash containing generated function, metadata (hash)
 
 =head1 SEE ALSO
 
@@ -368,7 +365,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Gen-FromClass>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Gen-FromClass>.
 
 =head1 BUGS
 
@@ -380,11 +377,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
